@@ -147,17 +147,16 @@ proc psplit {str sep} {
       set idx [string first $sep $str]
       while {$idx != -1} {
          # look ahead if found separator is escaped
-         if {[string index $str [expr {$idx-1}]] ne "\\"} {
+         if {[string index $str $idx-1] ne "\\"} {
             # unescape any separator character when adding to list
-            lappend res [charUnescaped [string range $str [expr {$previdx+1}]\
-               [expr {$idx-1}]] $sep]
+            lappend res [charUnescaped [string range $str $previdx+1 $idx-1]\
+               $sep]
             set previdx $idx
          }
-         set idx [string first $sep $str [expr {$idx+1}]]
+         set idx [string first $sep $str $idx+1]
       }
 
-      lappend res [charUnescaped [string range $str [expr {$previdx+1}] end]\
-         $sep]
+      lappend res [charUnescaped [string range $str $previdx+1 end] $sep]
    }
 
    return $res
@@ -260,6 +259,28 @@ proc getDiffBetweenList {list1 list2} {
    return [list $res1 $res2]
 }
 
+# return intersection of all lists: elements present in every list
+proc getIntersectBetweenList {args} {
+   foreach lst $args {
+      if {![info exists res]} {
+         set cur_res $lst
+      } else {
+         set cur_res [list]
+         foreach elt $res {
+            if {$elt in $lst} {
+               lappend cur_res $elt
+            }
+         }
+      }
+      set res $cur_res
+      # stop when intersection result becomes empty
+      if {[llength $res] == 0} {
+         break
+      }
+   }
+   return $res
+}
+
 # return elements from arr1 not in arr2, elements from arr1 in arr2 but with a
 # different value and elements from arr2 not in arr1.
 # if notset_equals_empty is enabled, not-set element in array is equivalent to
